[![Python](https://img.shields.io/badge/python-3.6%20%7C%203.7%20%7C%203.8-blue?style=plastic)](https://www.python.org/)
[![PyPI](https://img.shields.io/badge/pypi_package-1.0.12-blue?style=plastic)](https://pypi.org/project/skrobot/1.0.12/)
[![License](https://img.shields.io/badge/license-MIT-blue?style=plastic)](https://github.com/medoidai/skrobot/blob/master/LICENSE.txt)
[![Documentation Status](https://readthedocs.org/projects/skrobot/badge/?version=1.0.12)](https://skrobot.readthedocs.io/en/1.0.12/)

-----------------

[![skrobot logo](https://github.com/medoidai/skrobot/raw/master/static/skrobot-logo.png)](https://github.com/medoidai/skrobot/raw/master/static/skrobot-logo.png)

-----------------

# skrobot

## What is it about?

skrobot is a Python module for designing, running and tracking Machine Learning experiments / tasks. It is built on top of [scikit-learn](https://scikit-learn.org/) framework.

## Documentation?

The documentation is hosted online to [Read the Docs](https://skrobot.readthedocs.io/en/1.0.12/).

## How do I install it?

```sh
pip install skrobot
```

## Next Priorities?

* Add support in the module for multiclass problems

## Can I contribute?

Of course, the project is [Free Software](https://www.gnu.org/philosophy/free-sw.en.html) and you can contribute to it!

## What license do you use?

See our license ([LICENSE.txt](https://github.com/medoidai/skrobot/blob/master/LICENSE.txt)) for more details.

**Thank you!**